@@ -1,14 +1,14 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-"""APRS Cursor-on-Target Constants."""
+"""APRS Cursor-on-Target Gatway: Constants."""
 
 import logging
 import os
 import re
 
 __author__ = 'Greg Albrecht W2GMD <oss@undef.net>'
-__copyright__ = 'Copyright 2021 Greg Albrecht'
+__copyright__ = 'Copyright 2022 Greg Albrecht'
 __license__ = 'Apache License, Version 2.0'
 __source__ = 'https://github.com/ampledata/aprscot'
 
@@ -32,7 +32,7 @@ LL_REX = re.compile(
 DEFAULT_APRSIS_PORT: int = 14580
 DEFAULT_APRSIS_HOST: str = "rotate.aprs.net"
 DEFAULT_APRSIS_CALLSIGN: str = "APRSCOT"
-DEFAULT_APRSIS_FILTER: str = "f/SUNSET/50"
+DEFAULT_APRSIS_FILTER: str = "m/50"
 
 DEFAULT_COT_TYPE: str = "a-f-G-I-U-T-r"
 DEFAULT_COT_STALE: str = 3600
